package com.supwisdom.dlpay.system.controller;

import com.supwisdom.dlpay.api.bean.JsonResult;
import com.supwisdom.dlpay.framework.domain.TApiClient;
import com.supwisdom.dlpay.framework.domain.TBusinesspara;
import com.supwisdom.dlpay.framework.domain.TSyspara;
import com.supwisdom.dlpay.framework.service.SystemUtilService;
import com.supwisdom.dlpay.framework.util.PageResult;
import com.supwisdom.dlpay.framework.util.StringUtil;
import com.supwisdom.dlpay.framework.util.WebConstant;
import com.supwisdom.dlpay.system.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

@Controller
public class ParamController {
  @Autowired
  private ParamService paramService;
  @Autowired
  private SystemUtilService systemUtilService;

  @GetMapping("/param/syspara")
  public String sysparaView() {
    return "system/param/syspara";
  }

  @GetMapping("/param/sysparalist")
  @PreAuthorize("hasPermission('/param/syspara','')")
  @ResponseBody
  public PageResult<TSyspara> getDataList(@RequestParam("page") Integer pageNo,
                                          @RequestParam("limit") Integer pageSize,
                                          @RequestParam(value = "paraid", required = false) Integer paraid,
                                          @RequestParam(value = "paraname", required = false) String paraname) {
    try {
      if (null == pageNo || pageNo < 1) pageNo = WebConstant.PAGENO_DEFAULT;
      if (null == pageSize || pageSize < 1) pageSize = WebConstant.PAGESIZE_DEFAULT;
      return paramService.getSysparaPage(paraid, paraname, pageNo, pageSize);
    } catch (Exception e) {
      e.printStackTrace();
      return new PageResult<>(99, "系统查询错误");
    }
  }

  @PostMapping("/param/sysparaupdate")
  @PreAuthorize("hasPermission('/param/sysparaupdate','')")
  @ResponseBody
  public JsonResult updateSyspara(@RequestParam("paraid") Integer paraid,
                                  @RequestParam("paraval") String paraval) {
    if (null == paraid || null == paraval) {
      return JsonResult.error("参数传递错误");
    } else if (paraval.length() > 30) {
      return JsonResult.error("参数值过长");
    }
    TSyspara syspara = paramService.getSysparaByParaid(paraid);
    if (null == syspara) {
      return JsonResult.error("全局参数不存在");
    }
    syspara.setParaval(paraval);
    syspara.setLastsaved(systemUtilService.getSysdatetime().getHostdatetime());
    if (syspara.checkValueInvalid()) {
      return JsonResult.error("参数值格式错误");
    }
    try {
      if (paramService.updateSyspara(syspara)) {
        return JsonResult.ok("修改成功");
      } else {
        return JsonResult.error("修改失败");
      }
    } catch (Exception e) {
      e.printStackTrace();
      return JsonResult.error("系统处理异常").put("exception", e);
    }
  }


  /**
   * ====================================================
   * 业务参数配置
   * ====================================================
   */
  @GetMapping("/param/businesspara")
  public String busiparaView() {
    return "system/param/businesspara";
  }

  @GetMapping("/param/businessparalist")
  @PreAuthorize("hasPermission('/param/businesspara','')")
  @ResponseBody
  public PageResult<TBusinesspara> getBusinessDataList(@RequestParam("page") Integer pageNo,
                                               @RequestParam("limit") Integer pageSize,
                                               @RequestParam(value = "paraname", required = false) String paraname) {
    try {
      if (null == pageNo || pageNo < 1) pageNo = WebConstant.PAGENO_DEFAULT;
      if (null == pageSize || pageSize < 1) pageSize = WebConstant.PAGESIZE_DEFAULT;
      return paramService.getBusinessparaPage(paraname, pageNo, pageSize);
    } catch (Exception e) {
      e.printStackTrace();
      return new PageResult<>(99, "系统查询错误");
    }
  }

  @PostMapping("/param/deletebusinesspara")
  @PreAuthorize("hasPermission('/param/deletebusinesspara','')")
  @ResponseBody
  public JsonResult deleteBusinesspara(@RequestParam("parakey") String parakey) {
    try {
      if (StringUtil.isEmpty(parakey)) {
        return JsonResult.error("参数名为空");
      }
      TBusinesspara businesspara = paramService.getBusinessparaByParakey(parakey);
      if (null == businesspara) {
        return JsonResult.error("业务参数[" + parakey + "]不存在！");
      }
      if (paramService.deleteBusinesspara(businesspara)) {
        return JsonResult.ok("删除成功！");
      } else {
        return JsonResult.error("删除失败！");
      }
    } catch (Exception e) {
      e.printStackTrace();
      return JsonResult.error("系统处理异常").put("exception", e);
    }
  }

  @PostMapping("/param/businessparaupdate")
  @PreAuthorize("hasPermission('/param/businessparaupdate','')")
  @ResponseBody
  public JsonResult updateBusinesspara(@RequestParam("parakey") String parakey, @RequestParam("paraval") String paraval) {
    try {
      if (StringUtil.isEmpty(parakey) || null == paraval) {
        return JsonResult.error("参数传递错误");
      }
      TBusinesspara businesspara = paramService.getBusinessparaByParakey(parakey);
      if (null == businesspara) {
        return JsonResult.error("业务参数[" + parakey + "]不存在！");
      }
      businesspara.setParaval(paraval);
      if (paramService.saveOrUpdateBusinesspara(businesspara)) {
        return JsonResult.ok("修改成功！");
      } else {
        return JsonResult.error("修改失败！");
      }
    } catch (Exception e) {
      e.printStackTrace();
      return JsonResult.error("系统处理异常").put("exception", e);
    }
  }

  @GetMapping("/param/load4addbuspara")
  @PreAuthorize("hasPermission('/param/load4addbuspara','')")
  public String loadadd() {
    return "system/param/busparaform";
  }

  @GetMapping("/param/checkbusname")
  @ResponseBody
  public JsonResult checkname(@RequestParam("parakey") String parakey) {
    TBusinesspara businesspara = paramService.getBusinessparaByParakey(parakey);
    if (businesspara == null) {
      return JsonResult.ok();
    } else {
      return JsonResult.error("参数名重复");
    }
  }

  @PostMapping("/param/addbusinesspara")
  @PreAuthorize("hasPermission('/param/addbusinesspara','')")
  @ResponseBody
  public JsonResult addBusinesspara(@RequestParam("parakey") String parakey, @RequestParam("paraval") String paraval) {
    if (StringUtil.isEmpty(parakey) || null == paraval) {
      return JsonResult.error("参数传递错误");
    }
    try {
      TBusinesspara businesspara = paramService.getBusinessparaByParakey(parakey);
      if (null != businesspara) {
        return JsonResult.error("参数名重复");
      }
      businesspara = new TBusinesspara();
      businesspara.setParakey(parakey.trim());
      businesspara.setParaval(paraval.trim());
      if (paramService.saveOrUpdateBusinesspara(businesspara)) {
        return JsonResult.ok("新增成功！");
      } else {
        return JsonResult.error("新增失败！");
      }
    } catch (Exception e) {
      e.printStackTrace();
      return JsonResult.error("系统处理异常").put("exception", e);
    }
  }


  /**
   * ====================================================
   *            APPID应用权限参数管理
   * ====================================================
   */
  @GetMapping("/param/apiclientpara")
  public String appidParaView() {
    return "system/param/apiclientpara";
  }

  @GetMapping("/param/apiclientparalist")
  @PreAuthorize("hasPermission('/param/apiclientparalist','')")
  @ResponseBody
  public PageResult<TApiClient> getApiclientDataList(@RequestParam("page") Integer pageNo,
                                                     @RequestParam("limit") Integer pageSize,
                                                     @RequestParam(value = "appid", required = false) String appid) {
    try {
      if (null == pageNo || pageNo < 1) pageNo = WebConstant.PAGENO_DEFAULT;
      if (null == pageSize || pageSize < 1) pageSize = WebConstant.PAGESIZE_DEFAULT;
      return paramService.getApiClientparaPage(appid, pageNo, pageSize);
    } catch (Exception e) {
      e.printStackTrace();
      return new PageResult<>(99, "系统查询错误");
    }
  }


}
